==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/storage/kotlin/inputs/ManagementPolicySnapShotArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.storage.kotlin.inputs

import com.pulumi.azurenative.storage.inputs.ManagementPolicySnapShotArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Management policy action for snapshot.
 * @property delete The function to delete the blob snapshot
 * @property tierToArchive The function to tier blob snapshot to archive storage.
 * @property tierToCold The function to tier blobs to cold storage.
 * @property tierToCool The function to tier blob snapshot to cool storage.
 * @property tierToHot The function to tier blobs to hot storage. This action can only be used with Premium Block Blob Storage Accounts
 */
public data class ManagementPolicySnapShotArgs(
    public val delete: Output<DateAfterCreationArgs>? = null,
    public val tierToArchive: Output<DateAfterCreationArgs>? = null,
    public val tierToCold: Output<DateAfterCreationArgs>? = null,
    public val tierToCool: Output<DateAfterCreationArgs>? = null,
    public val tierToHot: Output<DateAfterCreationArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.storage.inputs.ManagementPolicySnapShotArgs> {
    override fun toJava(): com.pulumi.azurenative.storage.inputs.ManagementPolicySnapShotArgs =
        com.pulumi.azurenative.storage.inputs.ManagementPolicySnapShotArgs.builder()
            .delete(delete?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .tierToArchive(tierToArchive?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .tierToCold(tierToCold?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .tierToCool(tierToCool?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .tierToHot(tierToHot?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [ManagementPolicySnapShotArgs].
 */
@PulumiTagMarker
public class ManagementPolicySnapShotArgsBuilder internal constructor() {
    private var delete: Output<DateAfterCreationArgs>? = null

    private var tierToArchive: Output<DateAfterCreationArgs>? = null

    private var tierToCold: Output<DateAfterCreationArgs>? = null

    private var tierToCool: Output<DateAfterCreationArgs>? = null

    private var tierToHot: Output<DateAfterCreationArgs>? = null

    /**
     * @param value The function to delete the blob snapshot
     */
    @JvmName("xtnlavgfugtaetbc")
    public suspend fun delete(`value`: Output<DateAfterCreationArgs>) {
        this.delete = value
    }

    /**
     * @param value The function to tier blob snapshot to archive storage.
     */
    @JvmName("aeickqdkgqcgqtth")
    public suspend fun tierToArchive(`value`: Output<DateAfterCreationArgs>) {
        this.tierToArchive = value
    }

    /**
     * @param value The function to tier blobs to cold storage.
     */
    @JvmName("nqrllgpydvndehrb")
    public suspend fun tierToCold(`value`: Output<DateAfterCreationArgs>) {
        this.tierToCold = value
    }

    /**
     * @param value The function to tier blob snapshot to cool storage.
     */
    @JvmName("ekdfdngjqgekcteo")
    public suspend fun tierToCool(`value`: Output<DateAfterCreationArgs>) {
        this.tierToCool = value
    }

    /**
     * @param value The function to tier blobs to hot storage. This action can only be used with Premium Block Blob Storage Accounts
     */
    @JvmName("iefoavqeoasvuvty")
    public suspend fun tierToHot(`value`: Output<DateAfterCreationArgs>) {
        this.tierToHot = value
    }

    /**
     * @param value The function to delete the blob snapshot
     */
    @JvmName("xuiofxkqmaeansbc")
    public suspend fun delete(`value`: DateAfterCreationArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.delete = mapped
    }

    /**
     * @param argument The function to delete the blob snapshot
     */
    @JvmName("nyonvgwmydbmxpkc")
    public suspend fun delete(argument: suspend DateAfterCreationArgsBuilder.() -> Unit) {
        val toBeMapped = DateAfterCreationArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.delete = mapped
    }

    /**
     * @param value The function to tier blob snapshot to archive storage.
     */
    @JvmName("bcqywkcjestiskiu")
    public suspend fun tierToArchive(`value`: DateAfterCreationArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tierToArchive = mapped
    }

    /**
     * @param argument The function to tier blob snapshot to archive storage.
     */
    @JvmName("pwofdlklfsqyyqqk")
    public suspend fun tierToArchive(argument: suspend DateAfterCreationArgsBuilder.() -> Unit) {
        val toBeMapped = DateAfterCreationArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.tierToArchive = mapped
    }

    /**
     * @param value The function to tier blobs to cold storage.
     */
    @JvmName("tkglhfndimytvuqj")
    public suspend fun tierToCold(`value`: DateAfterCreationArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tierToCold = mapped
    }

    /**
     * @param argument The function to tier blobs to cold storage.
     */
    @JvmName("fplcwydkliabcobj")
    public suspend fun tierToCold(argument: suspend DateAfterCreationArgsBuilder.() -> Unit) {
        val toBeMapped = DateAfterCreationArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.tierToCold = mapped
    }

    /**
     * @param value The function to tier blob snapshot to cool storage.
     */
    @JvmName("iaauifnpkoamhqts")
    public suspend fun tierToCool(`value`: DateAfterCreationArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tierToCool = mapped
    }

    /**
     * @param argument The function to tier blob snapshot to cool storage.
     */
    @JvmName("ujbawbdfflmwniyn")
    public suspend fun tierToCool(argument: suspend DateAfterCreationArgsBuilder.() -> Unit) {
        val toBeMapped = DateAfterCreationArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.tierToCool = mapped
    }

    /**
     * @param value The function to tier blobs to hot storage. This action can only be used with Premium Block Blob Storage Accounts
     */
    @JvmName("rerdmsirwppkvsdh")
    public suspend fun tierToHot(`value`: DateAfterCreationArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tierToHot = mapped
    }

    /**
     * @param argument The function to tier blobs to hot storage. This action can only be used with Premium Block Blob Storage Accounts
     */
    @JvmName("hrpwtfbishclmgvu")
    public suspend fun tierToHot(argument: suspend DateAfterCreationArgsBuilder.() -> Unit) {
        val toBeMapped = DateAfterCreationArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.tierToHot = mapped
    }

    internal fun build(): ManagementPolicySnapShotArgs = ManagementPolicySnapShotArgs(
        delete = delete,
        tierToArchive = tierToArchive,
        tierToCold = tierToCold,
        tierToCool = tierToCool,
        tierToHot = tierToHot,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/storage/kotlin/inputs/ManagementPolicySnapShotArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.storage.kotlin.inputs

import com.pulumi.azurenative.storage.inputs.ManagementPolicySnapShotArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Management policy action for snapshot.
 * @property delete The function to delete the blob snapshot
 * @property tierToArchive The function to tier blob snapshot to archive storage.
 * @property tierToCold The function to tier blobs to cold storage.
 * @property tierToCool The function to tier blob snapshot to cool storage.
 * @property tierToHot The function to tier blobs to hot storage. This action can only be used with Premium Block Blob Storage Accounts
 */
public data class ManagementPolicySnapShotArgs(
    public val delete: Output<DateAfterCreationArgs>? = null,
    public val tierToArchive: Output<DateAfterCreationArgs>? = null,
    public val tierToCold: Output<DateAfterCreationArgs>? = null,
    public val tierToCool: Output<DateAfterCreationArgs>? = null,
    public val tierToHot: Output<DateAfterCreationArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.storage.inputs.ManagementPolicySnapShotArgs> {
    override fun toJava(): com.pulumi.azurenative.storage.inputs.ManagementPolicySnapShotArgs =
        com.pulumi.azurenative.storage.inputs.ManagementPolicySnapShotArgs.builder()
            .delete(delete?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .tierToArchive(tierToArchive?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .tierToCold(tierToCold?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .tierToCool(tierToCool?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .tierToHot(tierToHot?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [ManagementPolicySnapShotArgs].
 */
@PulumiTagMarker
public class ManagementPolicySnapShotArgsBuilder internal constructor() {
    private var delete: Output<DateAfterCreationArgs>? = null

    private var tierToArchive: Output<DateAfterCreationArgs>? = null

    private var tierToCold: Output<DateAfterCreationArgs>? = null

    private var tierToCool: Output<DateAfterCreationArgs>? = null

    private var tierToHot: Output<DateAfterCreationArgs>? = null

    /**
     * @param value The function to delete the blob snapshot
     */
    @JvmName("mprwodshuhbpstbe")
    public suspend fun delete(`value`: Output<DateAfterCreationArgs>) {
        this.delete = value
    }

    /**
     * @param value The function to tier blob snapshot to archive storage.
     */
    @JvmName("fhtrucmlvggtshxb")
    public suspend fun tierToArchive(`value`: Output<DateAfterCreationArgs>) {
        this.tierToArchive = value
    }

    /**
     * @param value The function to tier blobs to cold storage.
     */
    @JvmName("cmvfvqvqrxribcav")
    public suspend fun tierToCold(`value`: Output<DateAfterCreationArgs>) {
        this.tierToCold = value
    }

    /**
     * @param value The function to tier blob snapshot to cool storage.
     */
    @JvmName("mybtwixlemgwqnub")
    public suspend fun tierToCool(`value`: Output<DateAfterCreationArgs>) {
        this.tierToCool = value
    }

    /**
     * @param value The function to tier blobs to hot storage. This action can only be used with Premium Block Blob Storage Accounts
     */
    @JvmName("rurpepbdcjikpepx")
    public suspend fun tierToHot(`value`: Output<DateAfterCreationArgs>) {
        this.tierToHot = value
    }

    /**
     * @param value The function to delete the blob snapshot
     */
    @JvmName("pkabraefqxedireh")
    public suspend fun delete(`value`: DateAfterCreationArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.delete = mapped
    }

    /**
     * @param argument The function to delete the blob snapshot
     */
    @JvmName("bjxplwsevorgnlem")
    public suspend fun delete(argument: suspend DateAfterCreationArgsBuilder.() -> Unit) {
        val toBeMapped = DateAfterCreationArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.delete = mapped
    }

    /**
     * @param value The function to tier blob snapshot to archive storage.
     */
    @JvmName("njsvvnpgjvgmgmwt")
    public suspend fun tierToArchive(`value`: DateAfterCreationArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tierToArchive = mapped
    }

    /**
     * @param argument The function to tier blob snapshot to archive storage.
     */
    @JvmName("hswbvcgpqgyfxbyr")
    public suspend fun tierToArchive(argument: suspend DateAfterCreationArgsBuilder.() -> Unit) {
        val toBeMapped = DateAfterCreationArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.tierToArchive = mapped
    }

    /**
     * @param value The function to tier blobs to cold storage.
     */
    @JvmName("pjdatqdjnbpfrnvf")
    public suspend fun tierToCold(`value`: DateAfterCreationArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tierToCold = mapped
    }

    /**
     * @param argument The function to tier blobs to cold storage.
     */
    @JvmName("cqmvpcfhhgmoqpal")
    public suspend fun tierToCold(argument: suspend DateAfterCreationArgsBuilder.() -> Unit) {
        val toBeMapped = DateAfterCreationArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.tierToCold = mapped
    }

    /**
     * @param value The function to tier blob snapshot to cool storage.
     */
    @JvmName("nhsjqpkirkblpqaw")
    public suspend fun tierToCool(`value`: DateAfterCreationArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tierToCool = mapped
    }

    /**
     * @param argument The function to tier blob snapshot to cool storage.
     */
    @JvmName("jdyicriutefgoawj")
    public suspend fun tierToCool(argument: suspend DateAfterCreationArgsBuilder.() -> Unit) {
        val toBeMapped = DateAfterCreationArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.tierToCool = mapped
    }

    /**
     * @param value The function to tier blobs to hot storage. This action can only be used with Premium Block Blob Storage Accounts
     */
    @JvmName("hhpibipnawnakfir")
    public suspend fun tierToHot(`value`: DateAfterCreationArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tierToHot = mapped
    }

    /**
     * @param argument The function to tier blobs to hot storage. This action can only be used with Premium Block Blob Storage Accounts
     */
    @JvmName("bdiugkwqpsgffqsj")
    public suspend fun tierToHot(argument: suspend DateAfterCreationArgsBuilder.() -> Unit) {
        val toBeMapped = DateAfterCreationArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.tierToHot = mapped
    }

    internal fun build(): ManagementPolicySnapShotArgs = ManagementPolicySnapShotArgs(
        delete = delete,
        tierToArchive = tierToArchive,
        tierToCold = tierToCold,
        tierToCool = tierToCool,
        tierToHot = tierToHot,
    )
}
